@@ -60,6 +60,7 @@
 
 #include "wzd_structs.h"
 
+#include "wzd_commands.h"
 #include "wzd_log.h"
 #include "wzd_misc.h"
 #include "wzd_messages.h"
@@ -129,9 +130,6 @@ int do_site_test(wzd_string_t *command, wzd_string_t *param, wzd_context_t * con
   out_err(LEVEL_INFO,"# Childs     : %ld\n",mainConfig->stats.num_childs);
   ret = 0;
 
-  out_err(LEVEL_INFO,"sizeof(wzd_context_t) = %d\n", sizeof(wzd_context_t));
-  out_err(LEVEL_INFO,"sizeof(wzd_user_t) = %d\n", sizeof(wzd_user_t));
-
   fd_dump();
 
 #if 0
@@ -193,6 +191,50 @@ int do_site_test(wzd_string_t *command, wzd_string_t *param, wzd_context_t * con
   return 0;
 }
 
+/** Display generic help (controlled by the "help_file" config variable).
+ *
+ * If an argument is provided, the specific help function for this command is called. The help
+ * function must have been registered when calling \ref commands_add
+ */
+int do_site_help_command(wzd_string_t *command, wzd_string_t *command_line, wzd_context_t * context)
+{
+  wzd_string_t *argument, *str;
+  wzd_command_t * c;
+
+  argument = str_tok(command_line," \t\r\n");
+
+  if (argument) {
+    str_prepend(argument,"site_");
+    c = commands_find(mainConfig->commands_list,argument);
+    if (c == NULL) {
+      reply_push(context,"command does not exist");
+      reply_set_code(context,501);
+      return 0;
+    }
+
+    if (c->help_function == NULL) {
+      reply_push(context,"command does not provide help");
+      reply_set_code(context,200);
+      return 0;
+    }
+
+    return (c->help_function)(command,command_line,context);
+  }
+
+  /* generic help */
+  str = config_get_string(mainConfig->cfg_file,"GLOBAL","help_file",NULL);
+  if (str != NULL) {
+    do_site_print_file_raw(str_tochar(str),context);
+    str_deallocate(str);
+    return 0;
+  }
+
+  reply_push(context,"command ok");
+  reply_set_code(context,200);
+
+  return 0;
+}
+
 /********************* do_site_help ************************/
 
 void do_site_help(const char *site_command, wzd_context_t * context)
@@ -296,7 +338,7 @@ void do_site_help(const char *site_command, wzd_context_t * context)
 /********************* do_site_backend *********************/
 /** backend: close / reload / init / commit
  */
-int do_site_backend(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_backend(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * command, *name;
   int ret;
@@ -354,7 +396,7 @@ int do_site_backend(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
     if (ret) {
       ret = send_message_with_args(501,context,"Could not commit backend");
     } else {
-      ret = send_message_with_args(200,context,"Backend commited successfully");
+      ret = send_message_with_args(200,context,"Backend committed successfully");
     }
     str_deallocate(name);
     return 0;
@@ -369,7 +411,7 @@ int do_site_backend(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 /** chacl: user mode file1 [file2 ...]
  */
 
-int do_site_chacl(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chacl(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[BUFFER_LEN];
   wzd_string_t * mode, *username, *filename;
@@ -388,7 +430,7 @@ int do_site_chacl(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   user = GetUserByName( str_tochar(username) );
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"User does not exists");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 1;
   }
   mode = str_tok(command_line," \t\r\n");
@@ -432,7 +474,7 @@ int do_site_chacl(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 /** chgrp: group file1 [file2 ...]
  */
 
-int do_site_chgrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chgrp(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char * buffer;
   wzd_string_t * groupname, *filename;
@@ -447,7 +489,7 @@ int do_site_chgrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   /* check that groupname exists */
   group=GetGroupByName(str_tochar(groupname));
   if ( !group ) {
-    ret = send_message_with_args(501,context,"Group does not exists");
+    ret = send_message_with_args(501,context,"Group does not exist");
     str_deallocate(groupname);
     return 1;
   }
@@ -475,7 +517,7 @@ int do_site_chgrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 /********************* do_site_chmod ***********************/
 /** chmod: mode file1 [file2 ...]
  */
-int do_site_chmod(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chmod(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char * buffer;
   char * endptr;
@@ -545,7 +587,7 @@ int do_site_chmod(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 /** chown: user file1 [file2 ...]
  */
 
-int do_site_chown(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chown(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char * buffer;
   wzd_string_t * username, *filename;
@@ -560,7 +602,7 @@ int do_site_chown(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   /* check that username exists */
   user = GetUserByName(str_tochar(username));
   if ( !user ) {
-    ret = send_message_with_args(501,context,"User does not exists");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 1;
   }
 
@@ -591,7 +633,7 @@ int do_site_chown(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
  *   everyone can change their own password
  *   noone can change a siteops password except himself
  */
-int do_site_chpass(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chpass(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * username, *new_pass;
   int ret;
@@ -619,7 +661,7 @@ int do_site_chpass(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
     str_deallocate(username);
     username = NULL;
     if ( !user ) {
-      ret = send_message_with_args(501,context,"User does not exists");
+      ret = send_message_with_args(501,context,"User does not exist");
       str_deallocate(username); str_deallocate(new_pass);
       return 1;
     }
@@ -666,7 +708,7 @@ int do_site_chpass(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 }
 
 /********************* do_site_checkperm *******************/
-int do_site_checkperm(wzd_string_t *ignored, wzd_string_t * commandline, wzd_context_t * context)
+int do_site_checkperm(UNUSED wzd_string_t *ignored, wzd_string_t * commandline, wzd_context_t * context)
 {
   unsigned long word;
   char * buffer;
@@ -708,7 +750,7 @@ int do_site_checkperm(wzd_string_t *ignored, wzd_string_t * commandline, wzd_con
 
   /* convert file to absolute path, remember _setPerm wants ABSOLUTE paths ! */
   if (checkpath(str_tochar(filename),buffer,context)) {
-    send_message_with_args(501,context,"file does not exist");
+    send_message_with_args(501,context,"File does not exist");
     str_deallocate(filename);
     free(buffer);
     return 1;
@@ -718,9 +760,9 @@ int do_site_checkperm(wzd_string_t *ignored, wzd_string_t * commandline, wzd_con
 /*  buffer[strlen(buffer)-1] = '\0';*/ /* remove '/', appended by checkpath */
 
   if (_checkPerm(buffer,word,user)==0) {
-    wzd_strncpy(buffer,"right ok",WZD_MAX_PATH);
+    wzd_strncpy(buffer,"Right okay",WZD_MAX_PATH);
   } else {
-    wzd_strncpy(buffer,"refused",WZD_MAX_PATH);
+    wzd_strncpy(buffer,"Refused",WZD_MAX_PATH);
   }
 
   send_message_with_args(200,context,buffer);
@@ -732,7 +774,7 @@ int do_site_checkperm(wzd_string_t *ignored, wzd_string_t * commandline, wzd_con
 /** free sectionname
  */
 
-int do_site_free(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t * context)
+int do_site_free(UNUSED wzd_string_t *ignored, UNUSED wzd_string_t *param, wzd_context_t * context)
 {
   char * buffer;
   int ret;
@@ -755,7 +797,7 @@ int do_site_free(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
   buffer = malloc(WZD_MAX_PATH+1);
 
   if (checkpath_new(".",buffer,context)) {
-    send_message_with_args(501,context,". does not exist ?!");
+    send_message_with_args(501,context,". does not exist?!");
     free(buffer);
     return -1;
   }
@@ -788,7 +830,7 @@ int do_site_free(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
 /********************* do_site_invite **********************/
 /** invite: ircnick
  */
-int do_site_invite(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_invite(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * ircnick;
   int ret;
@@ -814,7 +856,7 @@ int do_site_invite(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
       (group->groupname)?group->groupname:"No Group",
       str_tochar(ircnick));
 
-  ret = send_message_with_args(200,context,"SITE INVITE command ok");
+  ret = send_message_with_args(200,context,"SITE INVITE command okay");
   str_deallocate(ircnick);
   return 0;
 }
@@ -824,7 +866,7 @@ int do_site_invite(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   * link: remove linkname
   */
 
-int do_site_link(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_link(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer_dir[BUFFER_LEN], buffer_link[BUFFER_LEN];
   wzd_string_t * dirname, *linkname;
@@ -845,7 +887,7 @@ int do_site_link(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
   /* convert file to absolute path, remember _setPerm wants ABSOLUTE paths ! */
   if (checkpath_new(str_tochar(dirname),buffer_dir,context)) {
-    ret = send_message_with_args(501,context,"dirname is invalid");
+    ret = send_message_with_args(501,context,"Dirname is invalid");
     str_deallocate(command); str_deallocate(dirname);
     return 0;
   }
@@ -863,7 +905,7 @@ int do_site_link(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
       return 1;
     }
     if ( (ret = checkpath_new(str_tochar(linkname),buffer_link,context) ) && ret != E_FILE_NOEXIST) { /* of course it returns no_exist */
-      ret = send_message_with_args(501,context,"linkname is invalid");
+      ret = send_message_with_args(501,context,"Linkname is invalid");
       str_deallocate(command);
       str_deallocate(linkname);
       return 0;
@@ -883,7 +925,7 @@ int do_site_link(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
     return 1;
   }
 
-  ret ? send_message_with_args(501,context,"command_failed") : send_message_with_args(200,context,"command ok");
+  ret ? send_message_with_args(501,context,"Command failed") : send_message_with_args(200,context,"Command okay");
   str_deallocate(command);
 
   return 0;
@@ -897,7 +939,7 @@ int do_site_link(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
  *       convert filename
  *       delete
  */
-int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_msg(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
 /*  int ret;*/
   wzd_string_t * command, * filename;
@@ -907,12 +949,12 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
   fs_filestat_t s;
 
   if (!mainConfig->dir_message) {
-    send_message_with_args(501,context,"no dir_message defined in config");
+    send_message_with_args(501,context,"No dir_message defined in config");
     return 1;
   }
 
   if (checkpath_new(".",msg_file,context)) {
-    send_message_with_args(501,context,". does not exist ?!");
+    send_message_with_args(501,context,". does not exist?!");
     return 1;
   } else {
     length = strlen(msg_file);
@@ -945,23 +987,23 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     str_deallocate(filename);
     if (fs_file_stat(other_file,&s) || !S_ISREG(s.mode))
     {
-      send_message_with_args(501,context,"inexistant file, or not a regular file");
+      send_message_with_args(501,context,"Inexistant file, or not a regular file");
       return -1;
     }
     unlink(msg_file);
     if (!safe_rename(other_file,msg_file))
     {
-      send_message_with_args(200,context,"message file loaded");
+      send_message_with_args(200,context,"Message file loaded");
       return 0;
     }
-    send_message_with_args(501,context,"error while renaming file");
+    send_message_with_args(501,context,"Error while renaming file");
     return -1;
   }
   else if (strcasecmp(str_tochar(command),"delete")==0)
   {
     str_deallocate(command);
     unlink(msg_file);
-    send_message_with_args(200,context,"message file deleted");
+    send_message_with_args(200,context,"Message file deleted");
     return 0;
   }
   else if (strcasecmp(str_tochar(command),"new")==0)
@@ -973,7 +1015,7 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     str_deallocate(command);
     fp = fopen(msg_file,"w");
     if (!fp) {
-      send_message_with_args(501,context,"unable to open message file for writing");
+      send_message_with_args(501,context,"Unable to open message file for writing");
       return 1;
     }
     buf = str_tok(command_line,"\r\n");
@@ -985,12 +1027,12 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     length = strlen(str_tochar(buf));
     if (length != fwrite(str_tochar(buf),1,length,fp)) {
       fclose(fp);
-      send_message_with_args(501,context,"unable to write message");
+      send_message_with_args(501,context,"Unable to write message");
       str_deallocate(buf);
       return 1;
     }
     fclose(fp);
-    send_message_with_args(200,context,"message file written");
+    send_message_with_args(200,context,"Message file written");
     str_deallocate(buf);
     return 0;
   }
@@ -1003,7 +1045,7 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     str_deallocate(command);
     fp = fopen(msg_file,"a");
     if (!fp) {
-      send_message_with_args(501,context,"unable to open message file for writing");
+      send_message_with_args(501,context,"Unable to open message file for writing");
       return 1;
     }
     buf = str_tok(command_line,"\r\n");
@@ -1015,12 +1057,12 @@ int do_site_msg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     length = strlen(str_tochar(buf));
     if (length != fwrite(str_tochar(buf),1,length,fp)) {
       fclose(fp);
-      send_message_with_args(501,context,"unable to write message");
+      send_message_with_args(501,context,"Unable to write message");
       str_deallocate(buf);
       return 1;
     }
     fclose(fp);
-    send_message_with_args(200,context,"message file written");
+    send_message_with_args(200,context,"Message file written");
     str_deallocate(buf);
     return 0;
   }
@@ -1045,7 +1087,7 @@ static int subcmp(const char * string, const char * substring)
  *        remove perm_name
  * XXX FIXME sort perms before sending !
  */
-int do_site_perm(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_perm(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
 /*  int ret;*/
   wzd_string_t * command_name, * perm_name, * ptr;
@@ -1124,8 +1166,8 @@ int do_site_perm(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
     str_deallocate(perm_name);
     str_deallocate(ptr);
-    if (ret) {send_message_with_args(501,context,"error changing permission"); return 1; }
-    send_message_with_args(200,context,"command ok, permission changed");
+    if (ret) {send_message_with_args(501,context,"Error changing permission"); return 1; }
+    send_message_with_args(200,context,"Command okay, permission changed");
     return -1;
   }
   else if (strcasecmp(str_tochar(command_name),"remove")==0)
@@ -1136,9 +1178,9 @@ int do_site_perm(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
       return 1;
     }
     if ( commands_delete_permission(mainConfig->commands_list,perm_name) )
-      send_message_with_args(501,context,"error, permission NOT deleted");
+      send_message_with_args(501,context,"Error, permission NOT deleted");
     else
-      send_message_with_args(200,context,"command ok, permission deleted");
+      send_message_with_args(200,context,"Command okay, permission deleted");
     str_deallocate(perm_name);
     return 0;
   }
@@ -1156,8 +1198,8 @@ int do_site_perm(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
     str_deallocate(perm_name);
     str_deallocate(ptr);
-    if (ret) {send_message_with_args(501,context,"error adding permission"); return 1; }
-    send_message_with_args(200,context,"command ok, permission changed");
+    if (ret) {send_message_with_args(501,context,"Error adding permission"); return 1; }
+    send_message_with_args(200,context,"Command okay, permission changed");
     return 0;
   }
 
@@ -1249,7 +1291,7 @@ void do_site_print_file_raw(const char *filename, wzd_context_t *context)
 
 /********************* do_site_reload **********************/
 
-int do_site_reload(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t * context)
+int do_site_reload(UNUSED wzd_string_t * ignored, UNUSED wzd_string_t *param, wzd_context_t * context)
 {
   int ret;
   pid_t pid;
@@ -1263,7 +1305,7 @@ int do_site_reload(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t *
   pid = getpid();
 #endif
   if (pid <2) {
-    ret = send_message_with_args(501,context,"ARG ! Getting invalid pid ?!");
+    ret = send_message_with_args(501,context,"ARG! Getting invalid pid?!");
     return 1;
   }
   out_log(LEVEL_CRITICAL,"Target pid: %d\n",pid);
@@ -1279,7 +1321,7 @@ int do_site_reload(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t *
 #else
   /* FIXME VISUAL : call server_restart explicitely ? */
   /*ret = send_message_with_args(501,context,"kill(getpid(),SIGHUP) not supported on visual ...");*/
-  ret = send_message_with_args(501, context, "restarting server, cross your fingers ...");
+  ret = send_message_with_args(501, context, "Restarting server, cross your fingers...");
   server_restart(SIGHUP);
   return 1;
 #endif
@@ -1288,7 +1330,7 @@ int do_site_reload(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t *
 
 /********************* do_site_rusage **********************/
 
-int do_site_rusage(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t * context)
+int do_site_rusage(UNUSED wzd_string_t * ignored, UNUSED wzd_string_t *param, wzd_context_t * context)
 {
 #ifndef WIN32
   int ret=0;
@@ -1402,13 +1444,13 @@ int do_site_rusage(wzd_string_t * ignored, wzd_string_t *param, wzd_context_t *
 
   send_message_raw("200 \r\n",context);
 #else /* _MSC_VER */
-  send_message_with_args(501,context,"can't be implemented on win32 !");
+  send_message_with_args(501,context,"Can't be implemented on win32!");
 #endif /* _MSC_VER */
   return 0;
 }
 
 /********************* do_site_savecfg *********************/
-int do_site_savecfg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_savecfg(UNUSED wzd_string_t *ignored, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * data = NULL;
   size_t length = 0, written;
@@ -1473,7 +1515,7 @@ int do_site_savecfg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 
   written = write(fd, str_tochar(data), length);
   if (written != length) {
-    out_log(LEVEL_HIGH,"ERROR Could not save config (written %d bytes instead of %d\n",written,length);
+    out_log(LEVEL_HIGH,"ERROR Could not save config (written %ld bytes instead of %ld\n",(long)written,(long)length);
   }
   close(fd);
 
@@ -1486,7 +1528,7 @@ int do_site_savecfg(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 /********************* do_site_sections ******************/
 /** Print all sections
  */
-int do_site_sections(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_sections(UNUSED wzd_string_t *ignored, UNUSED wzd_string_t *param, wzd_context_t * context)
 {
   wzd_section_t * section;
   wzd_string_t * buffer = str_allocate();
@@ -1506,11 +1548,61 @@ int do_site_sections(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
   return 0;
 }
 
+/** \brief Show last log messages (10 by default)
+ */
+int do_site_showlog(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+{
+  int i;
+  struct memory_log_t * log = get_log_buffer();
+  wzd_string_t * buffer = str_allocate();
+  int lines_to_show = 10;
+  int offset = 0;
+  char *ptr;
+  unsigned long ul;
+
+  /* check if we have an argument (the number of lines to display) */
+  if (str_length(command_line) > 0) {
+    ul = strtoul(str_tochar(command_line),&ptr,10);
+    if (ptr != NULL && *ptr == '\0' && ul < (long)log->size) {
+      lines_to_show = (int)ul;
+
+      /* change offset to match the last line to display */
+      for (i=log->size-1; i>=0; i--) {
+        if (log->data[i] != NULL) {
+          offset = i;
+          break;
+        }
+      }
+      /* then go back to print the correct number of lines */
+      offset -= lines_to_show;
+      if (offset < 0) offset = 0;
+
+    } else {
+      lines_to_show = log->size;
+    }
+  }
+
+  /* send header */
+  send_message_raw("200-\r\n",context);
+
+  for (i=offset; i<offset+lines_to_show; i++) {
+    if (log->data[i] != NULL) {
+      str_sprintf(buffer, " %s", log->data[i]);
+      send_message_raw(str_tochar(buffer),context);
+    }
+  }
+
+  send_message_raw("200 \r\n",context);
+  str_deallocate(buffer);
+
+  return 0;
+}
+
 /********************* do_site_unlock **********************/
 /** unlock: file1 [file2 ...]
  */
 
-int do_site_unlock(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_unlock(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[BUFFER_LEN];
   wzd_string_t * filename;
@@ -1539,7 +1631,7 @@ int do_site_unlock(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   while ( (filename = str_tok(command_line," \t\r\n")) );
 
   if (ret == 0) {
-    ret = send_message_with_args(200,context,"file(s) unlocked");
+    ret = send_message_with_args(200,context,"File(s) unlocked");
   } else {
     ret = send_message_with_args(501,context,"UNLOCK FAILED");
   }
@@ -1550,7 +1642,7 @@ int do_site_unlock(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 /** user username
  */
 
-int do_site_user(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_user(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   const char * username;
   int ret;
@@ -1568,7 +1660,7 @@ int do_site_user(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
   }
   /* check that username exists */
   if ( backend_find_user(username,&user,&uid) ) {
-    ret = send_message_with_args(501,context,"User does not exists");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
   if ( strchr(user.flags,FLAG_ULTRAHIDDEN )&&
@@ -1576,13 +1668,13 @@ int do_site_user(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
        (strcmp(username,me->username)!=0)/* do not hide to self ! */
      ) {
     /* for siteops we could send a different message, like 'user is hidden' */
-    ret = send_message_with_args(501,context,"User does not exists");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
   str = config_get_string(mainConfig->cfg_file,"GLOBAL","sitefile_user",NULL);
   if (!str) {
-    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_user does not exists");
+    ret = send_message_with_args(501,context,"File [GLOBAL] / sitefile_user does not exist");
     return 0;
   }
 
@@ -1597,7 +1689,7 @@ int do_site_user(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
  * change access time, modification time, modification of status of a file
  */
 
-int do_site_utime(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_utime(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
 #ifdef HAVE_STRPTIME
   extern char *strptime (__const char *__restrict __s,
@@ -1679,7 +1771,7 @@ int do_site_utime(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   utime_buf.modtime = mktime(&tm_mtime);
   /* convert file to absolute path, remember _setPerm wants ABSOLUTE paths ! */
   if (checkpath(str_tochar(filename),buffer,context)) { /* path is NOT ok ! */
-    ret = send_message_with_args(501,context,"File does not exists");
+    ret = send_message_with_args(501,context,"File does not exist");
     str_deallocate(filename);
     return 1;
   }
@@ -1693,13 +1785,13 @@ int do_site_utime(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   ret = utime(buffer,&utime_buf);
 
-  ret = send_message_with_args(200,context,"UTIME command ok");
+  ret = send_message_with_args(200,context,"UTIME command okay");
   return 0;
 }
 
 /********************* do_site_vars *********************/
 
-int do_site_vars(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_vars(UNUSED wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
 {
   wzd_string_t *command, *varname, *value;
   char * buffer;
@@ -1725,7 +1817,7 @@ int do_site_vars(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context
     ret = vars_get(str_tochar(varname),buffer,1024,mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_get");
     else
       send_message_with_args(200,context,buffer);
 
@@ -1745,16 +1837,16 @@ int do_site_vars(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context
     ret = vars_set(str_tochar(varname),str_tochar(value),strlen(str_tochar(value)),mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_set");
     else
-      send_message_with_args(200,context,"command ok");
+      send_message_with_args(200,context,"Command okay");
 
     str_deallocate(varname);
     str_deallocate(value);
     return 0;
   }
 
-  send_message_with_args(200,context,"command ok");
+  send_message_with_args(200,context,"Command okay");
   str_deallocate(command);
   str_deallocate(varname);
   return 0;
@@ -1762,7 +1854,7 @@ int do_site_vars(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context
 
 /****************** do_site_vars_group *******************/
 
-int do_site_vars_group(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_vars_group(UNUSED wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
 {
   wzd_string_t *groupname, *command, *varname, *value;
   char * buffer;
@@ -1785,7 +1877,7 @@ int do_site_vars_group(wzd_string_t *ignored, wzd_string_t * command_line, wzd_c
   group = GetGroupByName(str_tochar(groupname));
   str_deallocate(groupname);
   if ( !group ) {
-    send_message_with_args(501,context,"group does not exist");
+    send_message_with_args(501,context,"Group does not exist");
     str_deallocate(command);
     return 1;
   }
@@ -1803,7 +1895,7 @@ int do_site_vars_group(wzd_string_t *ignored, wzd_string_t * command_line, wzd_c
     ret = vars_group_get(group->groupname,str_tochar(varname),buffer,1024,mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_group_get");
     else
       send_message_with_args(200,context,buffer);
 
@@ -1823,15 +1915,15 @@ int do_site_vars_group(wzd_string_t *ignored, wzd_string_t * command_line, wzd_c
     ret = vars_group_set(group->groupname,str_tochar(varname),str_tochar(value),strlen(str_tochar(value)),mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_group_set");
     else
-      send_message_with_args(200,context,"command ok");
+      send_message_with_args(200,context,"Command okay");
     str_deallocate(value);
     str_deallocate(varname);
     return 0;
   }
 
-  send_message_with_args(200,context,"command ok");
+  send_message_with_args(200,context,"Command okay");
   str_deallocate(command);
   str_deallocate(varname);
   return 0;
@@ -1839,7 +1931,7 @@ int do_site_vars_group(wzd_string_t *ignored, wzd_string_t * command_line, wzd_c
 
 /****************** do_site_vars_user *******************/
 
-int do_site_vars_user(wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_vars_user(UNUSED wzd_string_t *ignored, wzd_string_t * command_line, wzd_context_t * context)
 {
   wzd_string_t *username, *command, *varname, *value;
   char * buffer;
@@ -1862,7 +1954,7 @@ int do_site_vars_user(wzd_string_t *ignored, wzd_string_t * command_line, wzd_co
   user = GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    send_message_with_args(501,context,"user does not exist");
+    send_message_with_args(501,context,"User does not exist");
     str_deallocate(command);
     return 1;
   }
@@ -1880,7 +1972,7 @@ int do_site_vars_user(wzd_string_t *ignored, wzd_string_t * command_line, wzd_co
     ret = vars_user_get(user->username,str_tochar(varname),buffer,1024,mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_user_get");
     else
       send_message_with_args(200,context,buffer);
 
@@ -1901,22 +1993,22 @@ int do_site_vars_user(wzd_string_t *ignored, wzd_string_t * command_line, wzd_co
     ret = vars_user_set(user->username,str_tochar(varname),str_tochar(value),strlen(str_tochar(value)),mainConfig);
 
     if (ret)
-      send_message_with_args(200,context,"an error occurred");
+      send_message_with_args(200,context,"An error occurred inside vars_user_set");
     else
-      send_message_with_args(200,context,"command ok");
+      send_message_with_args(200,context,"Command okay");
     str_deallocate(varname);
     str_deallocate(value);
     return 0;
   }
 
-  send_message_with_args(200,context,"command ok");
+  send_message_with_args(200,context,"Command okay");
   str_deallocate(varname);
   return 0;
 }
 
 /********************* do_site_version *********************/
 
-int do_site_version(wzd_string_t * ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_version(UNUSED wzd_string_t * ignored, UNUSED wzd_string_t * param, wzd_context_t * context)
 {
   char str[256];
   snprintf(str,256,"%s build %s (%s)",
@@ -1929,7 +2021,7 @@ int do_site_version(wzd_string_t * ignored, wzd_string_t * command_line, wzd_con
 /** vfsadd |/home/vfsroot|/physical/path| +O =user
  */
 
-int do_site_vfsadd(wzd_string_t * ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_vfsadd(UNUSED wzd_string_t * ignored, wzd_string_t * command_line, wzd_context_t * context)
 {
   char *vpath, *ppath, *target;
 /*  int i;*/
@@ -2004,7 +2096,7 @@ int do_site_vfsadd(wzd_string_t * ignored, wzd_string_t * command_line, wzd_cont
     snprintf( tmp, 80, "vfs %s already set", vpath );
     send_message_with_args(501,context,tmp);
   }  else
-    send_message_with_args(200,context,"VFSADD command ok");
+    send_message_with_args(200,context,"VFSADD command okay");
 
   free(vpath); free(ppath);
 
@@ -2015,7 +2107,7 @@ int do_site_vfsadd(wzd_string_t * ignored, wzd_string_t * command_line, wzd_cont
 /** vfsdel /home/vfsroot
  */
 
-int do_site_vfsdel(wzd_string_t * ignored, wzd_string_t * command_line, wzd_context_t * context)
+int do_site_vfsdel(UNUSED wzd_string_t * ignored, wzd_string_t * command_line, wzd_context_t * context)
 {
   int ret;
 
@@ -2031,7 +2123,7 @@ int do_site_vfsdel(wzd_string_t * ignored, wzd_string_t * command_line, wzd_cont
     snprintf( tmp, 80, "vfs %s does not exist", str_tochar(command_line) );
     send_message_with_args(501,context,tmp);
   } else
-    send_message_with_args(200,context,"VFSDEL command ok");
+    send_message_with_args(200,context,"VFSDEL command okay");
 
   return 0;
 }
@@ -2099,7 +2191,7 @@ static int do_internal_wipe(const char *filename, wzd_context_t * context)
 /** wipe: [-r] file1 [file2 ...]
  */
 
-int do_site_wipe(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_wipe(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[WZD_MAX_PATH+1];
   wzd_string_t * firstarg, *filename;
@@ -2145,7 +2237,7 @@ int do_site_wipe(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
     }
     if (ret != EVENT_OK && ret != EVENT_BREAK) {
       out_log(LEVEL_NORMAL, "Wipe denied by hook (returned %d)\n", ret);
-      ret = send_message_with_args(501,context,"Wipe denied");
+      ret = send_message_with_args(501,context,"WIPE denied");
       str_deallocate(filename);
       return E_COMMAND_FAILED;
     }
