@@ -77,16 +77,17 @@ static int _kick_and_purge(void);
 
 
 
-void do_site_help_adduser(wzd_context_t * context)
+int do_site_help_adduser(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site adduser <user> <password> [<group>] [<ip1> <ip2> <...>]");
+  return 0;
 }
 
 /** site adduser: adds a new user
  *
  * adduser &lt;user&gt; &lt;password&gt; [&lt;group&gt;] [&lt;ip1&gt; &lt;ip2&gt; &lt;...&gt;]
  */
-int do_site_adduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_adduser(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * username, *password, *groupname, *ip=NULL;
   int ret;
@@ -101,14 +102,12 @@ int do_site_adduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_adduser(context);
-    return 0;
+    return do_site_help_adduser(cname,command_line,context);
   }
   password = str_tok(command_line," \t\r\n");
   if (!password) {
-    do_site_help_adduser(context);
     str_deallocate(username);
-    return 0;
+    return do_site_help_adduser(cname,command_line,context);
   }
 
   groupname = str_tok(command_line," \t\r\n");
@@ -128,7 +127,7 @@ int do_site_adduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
     if (me && me->group_num>0) {
       group = GetGroupByID(me->groups[0]);
     } else {
-      ret = send_message_with_args(501,context,"You cannot add users due to your own groups");
+      ret = send_message_with_args(501,context,"You need to be a member of at least one group");
       str_deallocate(username); str_deallocate(password); str_deallocate(ip);
       return 0;
     }
@@ -162,7 +161,7 @@ int do_site_adduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
         err = send_message_with_args(501,context,"Invalid name or parameter");
         break;
       case E_PARAM_EXIST:
-        err = send_message_with_args(501,context,"A user already exist with this name");
+        err = send_message_with_args(501,context,"A user already exists with this name");
         break;
       default:
         err = send_message_with_args(501,context,"Error while adding user");
@@ -197,16 +196,17 @@ int do_site_adduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
   return 0;
 }
 
-void do_site_help_deluser(wzd_context_t * context)
+int do_site_help_deluser(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
-  send_message_with_args(501,context,"site deluser <user> [<backend>]");
+  send_message_with_args(501,context,"site deluser <user>");
+  return 0;
 }
 
 /** site deluser: delete user
  *
  * deluser &lt;user&gt;
  */
-int do_site_deluser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_deluser(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * username;
   int ret;
@@ -219,10 +219,8 @@ int do_site_deluser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_deluser(context);
-    return 0;
+    return do_site_help_deluser(cname,command_line,context);
   }
-  /* TODO read backend */
 
   /* check if user already exists */
   user = GetUserByName(str_tochar(username));
@@ -257,21 +255,23 @@ int do_site_deluser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 
   /* commit changes to backend */
   backend_mod_user(mainConfig->backends->filename,user->uid,user,_USER_FLAGS);
+  backend_commit_changes(mainConfig->backends->filename);
 
   ret = send_message_with_args(200,context,"User deleted");
   return 0;
 }
 
-void do_site_help_readduser(wzd_context_t * context)
+int do_site_help_readduser(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
-  send_message_with_args(501,context,"site readduser <user> [<backend>]");
+  send_message_with_args(501,context,"site readduser <user>");
+  return 0;
 }
 
 /** site readduser: undelete user
  *
  * readduser &lt;user&gt;
  */
-int do_site_readduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_readduser(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * username;
@@ -285,8 +285,7 @@ int do_site_readduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_readduser(context);
-    return 0;
+    return do_site_help_readduser(cname,command_line,context);
   }
 
   /* check if user exists */
@@ -328,9 +327,9 @@ int do_site_readduser(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
 
 /** site purge: delete user permanently
  *
- * purge [&lt;user&gt;] [&lt;backend&gt;]
+ * purge [&lt;user&gt;]
  */
-int do_site_purgeuser(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t * context)
+int do_site_purgeuser(UNUSED wzd_string_t *ignored, wzd_string_t *param, wzd_context_t * context)
 {
   wzd_string_t * username;
   int ret;
@@ -402,16 +401,17 @@ int do_site_purgeuser(wzd_string_t *command_line, wzd_string_t *param, wzd_conte
   return 0;
 }
 
-void do_site_help_addip(wzd_context_t * context)
+int do_site_help_addip(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site addip <user> <ip1> [<ip2> ...]");
+  return 0;
 }
 
 /** site addip: adds an ip to a user
  *
  * addip &lt;user&gt; &lt;ip1&gt; [&lt;ip2&gt; ...]
  */
-int do_site_addip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_addip(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * username, *ip;
   int ret;
@@ -423,8 +423,7 @@ int do_site_addip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_addip(context);
-    return 0;
+    return do_site_help_addip(cname,command_line,context);
   }
 
   /* check if user  exists */
@@ -437,8 +436,7 @@ int do_site_addip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   ip = str_tok(command_line," \t\r\n");
   if (!ip) {
-    do_site_help_addip(context);
-    return 0;
+    return do_site_help_addip(cname,command_line,context);
   }
 
   /* GAdmin ? */
@@ -455,7 +453,7 @@ int do_site_addip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
     ret = ip_inlist(user->ip_list, str_tochar(ip));
     if (ret) {
-      ret = send_message_with_args(501,context,"ip is already included in list");
+      ret = send_message_with_args(501,context,"IP address is already included in list");
       str_deallocate(ip);
       return 0;
     }
@@ -469,14 +467,15 @@ int do_site_addip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   /* commit to backend */
   backend_mod_user(mainConfig->backends->filename,user->uid,user,_USER_IP);
 
-  ret = send_message_with_args(200,context,"User ip(s) added");
+  ret = send_message_with_args(200,context,"User IP address(es) added");
   return 0;
 }
 
-void do_site_help_delip(wzd_context_t * context)
+int do_site_help_delip(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-Usage: site delip <user> <ip1> [<ip2> ...]\r\n",context);
   send_message_raw("501  ip can be replaced by the slot_number (get it with site user <user>)\r\n",context);
+  return 0;
 }
 
 /** site delip: removes ip from user
@@ -485,7 +484,7 @@ void do_site_help_delip(wzd_context_t * context)
  *
  * ip can be replaced by the slot_number
  */
-int do_site_delip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_delip(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr_ul;
   wzd_string_t * username, *ip;
@@ -499,8 +498,7 @@ int do_site_delip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_delip(context);
-    return 0;
+    return do_site_help_delip(cname,command_line,context);
   }
   /* check if user  exists */
   user = GetUserByName(str_tochar(username));
@@ -521,8 +519,7 @@ int do_site_delip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   ip = str_tok(command_line," \t\r\n");
   if (!ip) {
-    do_site_help_delip(context);
-    return 0;
+    return do_site_help_delip(cname,command_line,context);
   }
 
   do {
@@ -570,7 +567,7 @@ int do_site_delip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
 
   /* commit to backend */
   backend_mod_user(mainConfig->backends->filename,user->uid,user,_USER_IP);
-  ret = send_message_with_args(200,context,"User ip(s) removed");
+  ret = send_message_with_args(200,context,"User IP address(es) removed");
   return 0;
 }
 
@@ -579,7 +576,7 @@ int do_site_delip(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
  *
  * change color
  */
-int do_site_color(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t * context)
+int do_site_color(UNUSED wzd_string_t *ignored, UNUSED wzd_string_t *param, wzd_context_t * context)
 {
   wzd_user_t * me;
   char * src_ptr, *dst_ptr;
@@ -601,18 +598,18 @@ int do_site_color(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
     *dst_ptr='\0';
     memcpy(me->flags,new_flags,MAX_FLAGS_NUM);
     ret = backend_mod_user(mainConfig->backends->filename,me->uid,me,_USER_FLAGS);
-    ret = send_message_with_args(200,context,"color mode ON");
+    ret = send_message_with_args(200,context,"Color mode ON");
   } else {
     *dst_ptr='\0';
     memcpy(me->flags,new_flags,MAX_FLAGS_NUM);
     ret = backend_mod_user(mainConfig->backends->filename,me->uid,me,_USER_FLAGS);
-    ret = send_message_with_args(200,context,"color mode OFF");
+    ret = send_message_with_args(200,context,"Color mode OFF");
   }
   return 0;
 }
 
 
-void do_site_help_change(wzd_context_t * context)
+int do_site_help_change(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-site change <user> <field> <value>\r\n",context);
   send_message_raw("field can be one of:\r\n",context);
@@ -633,13 +630,15 @@ void do_site_help_change(wzd_context_t * context)
   send_message_raw(" leech_slots changes allowed leech slots (for GAdmins)\r\n",context);
 
   send_message_raw("501 site change aborted\r\n",context);
+
+  return 0;
 }
 
 /** site change: change a field for a user
  *
  * change &lt;user&gt; &lt;field&gt; &lt;value&gt;
  */
-int do_site_change(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_change(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * username, * field, * value;
@@ -658,8 +657,7 @@ int do_site_change(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_change(context);
-    return 0;
+    return do_site_help_change(cname,command_line,context);
   }
   /* check if user  exists */
   strncpy(old_username,str_tochar(username),HARD_USERNAME_LENGTH);
@@ -672,14 +670,12 @@ int do_site_change(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   }
   field = str_tok(command_line," \t\r\n");
   if (!field) {
-    do_site_help_change(context);
-    return 0;
+    return do_site_help_change(cname,command_line,context);
   }
   value = str_tok(command_line,"\r\n");
   if (!value) {
-    do_site_help_change(context);
     str_deallocate(field);
-    return 0;
+    return do_site_help_change(cname,command_line,context);
   }
 
   uid = user->uid;
@@ -857,7 +853,7 @@ int do_site_change(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   }
   /* bytes_ul and bytes_dl should never be changed ... */
   else {
-    ret = send_message_with_args(501,context,"field does not exist");
+    ret = send_message_with_args(501,context,"Field does not exist");
     str_deallocate(field); str_deallocate(value);
     return 0;
   }
@@ -887,29 +883,31 @@ int do_site_change(wzd_string_t *ignored, wzd_string_t *command_line, wzd_contex
   if ( (user->flags && strchr(user->flags,FLAG_GADMIN)) &&
       (user->flags && strchr(user->flags,FLAG_SITEOP)))
   {
-    ret = send_message_with_args(200,context,"Change ok - You have set flags G and O, THIS IS NOT WHAT YOU WANT - repeat: THIS IS STUPID !!");
+    ret = send_message_with_args(200,context,"Change okay - You have set flags G and O, THIS IS NOT WHAT YOU WANT - repeat: THIS IS STUPID !!");
   }
   else
-    ret = send_message_with_args(200,context,"User field change successfull");
+    ret = send_message_with_args(200,context,"User field change successful");
 
   str_deallocate(field); str_deallocate(value);
 
   return 0;
 }
 
-void do_site_help_changegrp(wzd_context_t * context)
+int do_site_help_changegrp(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_raw("501-site changegrp <user> <group1> [<group2> ...]\r\n",context);
   send_message_raw(" Add user to group, or remove it if already in group\r\n",context);
 
   send_message_raw("501 site changegrp aborted\r\n",context);
+
+  return 0;
 }
 
 /** site changegrp: add/remove user from group
  *
  * changegrp &lt;user&gt; &lt;group1&gt; [&lt;group2&gt; ...]
  */
-int do_site_changegrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_changegrp(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t * username, * group_name;
   unsigned long mod_type;
@@ -919,22 +917,20 @@ int do_site_changegrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_changegrp(context);
-    return 0;
+    return do_site_help_changegrp(cname,command_line,context);
   }
 
   /* check if user exists */
   user=GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"user does not exist");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
   group_name = str_tok(command_line," \t\r\n");
   if (!group_name) {
-    do_site_help_changegrp(context);
-    return 0;
+    return do_site_help_changegrp(cname,command_line,context);
   }
 
   /* find modification type */
@@ -975,22 +971,23 @@ int do_site_changegrp(wzd_string_t *ignored, wzd_string_t *command_line, wzd_con
   /* commit to backend */
   backend_mod_user(mainConfig->backends->filename,user->uid,user,mod_type);
 
-  ret = send_message_with_args(200,context,"User field change successfull");
+  ret = send_message_with_args(200,context,"User field change successful");
   return 0;
 }
 
 
 
-void do_site_help_chratio(wzd_context_t * context)
+int do_site_help_chratio(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site chratio <user> <ratio>");
+  return 0;
 }
 
 /** site chratio: change user ratio
  *
  * chratio user ratio
  */
-int do_site_chratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_chratio(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr=NULL;
   wzd_string_t * str_ratio, *username;
@@ -1004,29 +1001,26 @@ int do_site_chratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_chratio(context);
-    return 0;
+    return do_site_help_chratio(cname,command_line,context);
   }
   str_ratio = str_tok(command_line," \t\r\n");
   if (!str_ratio) {
-    do_site_help_chratio(context);
     str_deallocate(username);
-    return 0;
+    return do_site_help_chratio(cname,command_line,context);
   }
 
   /* check if user exists */
   user=GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"user does not exist");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
   ratio = strtoul(str_tochar(str_ratio),&ptr,0);
 
   if (*ptr!='\0') {
-    do_site_help_chratio(context);
-    return 0;
+    return do_site_help_chratio(cname,command_line,context);
   }
   str_deallocate(str_ratio);
 
@@ -1077,7 +1071,7 @@ int do_site_chratio(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
  *
  * flags &lt;user&gt; &lt;newflags&gt;
  */
-int do_site_flags(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_flags(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[1024];
   wzd_string_t *newflags = NULL;
@@ -1097,7 +1091,7 @@ int do_site_flags(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
   user=GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"user does not exist");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
@@ -1150,7 +1144,7 @@ int do_site_flags(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context
  *
  * NOTE: you need to be siteop to change your idletime
  */
-int do_site_idle(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_idle(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[1024];
   char *ptr;
@@ -1162,13 +1156,13 @@ int do_site_idle(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
   user = GetUserByID(context->userid);
   /* check if user exists */
   if ( !user ) {
-    ret = send_message_with_args(501,context,"Mama says I don't exist ?!");
+    ret = send_message_with_args(501,context,"Mama says I don't exist?!");
     return 0;
   }
 
   if (command_line && strlen(str_tochar(command_line))>0) {
     if (!user->flags || !strchr(user->flags,FLAG_SITEOP)) {
-      ret = send_message_with_args(501,context,"You do not have the rights to do that !");
+      ret = send_message_with_args(501,context,"You do not have the rights to do that!");
       return 0;
     }
     idletime = strtoul(str_tochar(command_line),&ptr,0);
@@ -1179,7 +1173,7 @@ int do_site_idle(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
     user->max_idle_time = idletime;
     /* commit to backend */
     backend_mod_user(mainConfig->backends->filename,user->uid,user,_USER_IDLE);
-    snprintf(buffer,1023,"%s","Command ok");
+    snprintf(buffer,1023,"%s","Command okay");
   } else { /* if (*command_line != '\0') */
 
     snprintf(buffer,1023,"Your idle time is %u",user->max_idle_time);
@@ -1193,7 +1187,7 @@ int do_site_idle(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
  *
  * tagline [&lt;tagline&gt;]
  */
-int do_site_tagline(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_tagline(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char buffer[1024];
   int ret;
@@ -1203,7 +1197,7 @@ int do_site_tagline(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
   user = GetUserByID(context->userid);
   /* check if user exists */
   if ( !user ) {
-    ret = send_message_with_args(501,context,"Mama says I don't exist ?!");
+    ret = send_message_with_args(501,context,"Mama says I don't exist?!");
     return 0;
   }
 
@@ -1211,7 +1205,7 @@ int do_site_tagline(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
     strncpy(user->tagline,str_tochar(command_line),255);
     /* commit to backend */
     backend_mod_user(mainConfig->backends->filename,user->uid,user,_USER_TAGLINE);
-    snprintf(buffer,1023,"%s","Command ok");
+    snprintf(buffer,1023,"%s","Command okay");
   } else { /* if (*command_line != '\0') */
 
     snprintf(buffer,1023,"Your tagline is %s",user->tagline);
@@ -1226,7 +1220,7 @@ int do_site_tagline(wzd_string_t *ignored, wzd_string_t *command_line, wzd_conte
  *
  * kill &lt;pid&gt;
  */
-int do_site_kill(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t * context)
+int do_site_kill(UNUSED wzd_string_t *ignored, wzd_string_t *param, wzd_context_t * context)
 {
   char *ptr;
   int ret;
@@ -1243,13 +1237,13 @@ int do_site_kill(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
     ret = send_message_with_args(200,context,"KILL signal sent");
     break;
   case 1:
-    ret = send_message_with_args(501,context,"My religion forbids me suicide !");
+    ret = send_message_with_args(501,context,"My religion forbids me suicide!");
     break;
   case -1:
     ret = send_message_with_args(501,context,"Invalid PID");
     break;
   default:
-    ret = send_message_with_args(501,context,"We should NOT have passed here - NEVER !");
+    ret = send_message_with_args(501,context,"We should NOT have passed here - NEVER!");
     break;
   }
 
@@ -1260,7 +1254,7 @@ int do_site_kill(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
  *
  * kick &lt;user&gt;
  */
-int do_site_kick(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t * context)
+int do_site_kick(UNUSED wzd_string_t *ignored, wzd_string_t *param, wzd_context_t * context)
 {
   wzd_string_t *username;
   int ret;
@@ -1282,7 +1276,7 @@ int do_site_kick(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
 
   /* preliminary check: i can't kill myself */
   if (user->uid == context->userid) {
-    ret = send_message_with_args(501,context,"My religion forbids me suicide !");
+    ret = send_message_with_args(501,context,"My religion forbids me suicide!");
     return 0;
   }
 
@@ -1300,7 +1294,7 @@ int do_site_kick(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
       }
     } /* for all contexts */
   }
-  if (!found) { ret = send_message_with_args(501,context,"User is not logged !"); }
+  if (!found) { ret = send_message_with_args(501,context,"User is not logged!"); }
   else { ret = send_message_with_args(200,context,"KILL signal sent"); }
 
   return 0;
@@ -1311,7 +1305,7 @@ int do_site_kick(wzd_string_t *command_line, wzd_string_t *param, wzd_context_t
  *
  * killpath &lt;path&gt;
  */
-int do_site_killpath(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_killpath(UNUSED wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *realpath;
   wzd_string_t *path;
@@ -1334,13 +1328,13 @@ int do_site_killpath(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
 
   switch (ret) {
     case E_FILE_NOEXIST:
-      ret = send_message_with_args(501,context,"path does not exist !");
+      ret = send_message_with_args(501,context,"Path does not exist!");
       break;
     case E_USER_IDONTEXIST:
-      ret = send_message_with_args(501,context,"Where am I ? My path does not exist !");
+      ret = send_message_with_args(501,context,"Where am I? My path does not exist!");
       break;
     case E_USER_ICANTSUICIDE:
-      ret = send_message_with_args(501,context,"My religion forbids me suicide !");
+      ret = send_message_with_args(501,context,"My religion forbids me suicide!");
       break;
     case E_USER_NOBODY:
       ret = send_message_with_args(200,context,"Nobody in this path");
@@ -1356,16 +1350,17 @@ int do_site_killpath(wzd_string_t *ignored, wzd_string_t *command_line, wzd_cont
   return 0;
 }
 
-void do_site_help_give(wzd_context_t * context)
+int do_site_help_give(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site give <user> <kbytes>");
+  return 0;
 }
 
 /** site give: gives credits to user
  *
  * give user kbytes
  */
-int do_site_give(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_give(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * str_give, *username;
@@ -1379,29 +1374,26 @@ int do_site_give(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_give(context);
-    return 0;
+    return do_site_help_give(cname,command_line,context);
   }
   str_give = str_tok(command_line," \t\r\n");
   if (!str_give) {
-    do_site_help_give(context);
     str_deallocate(username);
-    return 0;
+    return do_site_help_give(cname,command_line,context);
   }
 
   /* check if user exists */
   user=GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"user does not exist");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
   kbytes = strtoull(str_tochar(str_give),&ptr,0);
   if (*ptr!='\0') {
-    do_site_help_give(context);
     str_deallocate(str_give);
-    return 0;
+    return do_site_help_give(cname,command_line,context);
   }
   str_deallocate(str_give);
   kbytes *= 1024;
@@ -1421,7 +1413,7 @@ int do_site_give(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
   /* check user credits */
   if (me->credits && me->credits < kbytes) {
-    ret = send_message_with_args(501,context,"You don't have enough credits !");
+    ret = send_message_with_args(501,context,"You don't have enough credits!");
     return 0;
   }
 
@@ -1440,16 +1432,17 @@ int do_site_give(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
   return 0;
 }
 
-void do_site_help_take(wzd_context_t * context)
+int do_site_help_take(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site take <user> <kbytes>");
+  return 0;
 }
 
 /** site take: removes credits to user
  *
  * take user kbytes
  */
-int do_site_take(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_take(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   char *ptr;
   wzd_string_t * str_take, *username;
@@ -1463,29 +1456,26 @@ int do_site_take(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_take(context);
-    return 0;
+    return do_site_help_take(cname,command_line,context);
   }
   str_take = str_tok(command_line," \t\r\n");
   if (!str_take) {
-    do_site_help_take(context);
     str_deallocate(username);
-    return 0;
+    return do_site_help_take(cname,command_line,context);
   }
 
   /* check if user exists */
   user=GetUserByName(str_tochar(username));
   str_deallocate(username);
   if ( !user ) {
-    ret = send_message_with_args(501,context,"user does not exist");
+    ret = send_message_with_args(501,context,"User does not exist");
     return 0;
   }
 
   kbytes = strtoull(str_tochar(str_take),&ptr,0);
   if (*ptr!='\0') {
-    do_site_help_take(context);
     str_deallocate(str_take);
-    return 0;
+    return do_site_help_take(cname,command_line,context);
   }
   str_deallocate(str_take);
   kbytes *= 1024;
@@ -1505,7 +1495,7 @@ int do_site_take(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 
   /* check user credits */
   if (user->ratio==0) {
-    ret = send_message_with_args(501,context,"User has unlimited credits !");
+    ret = send_message_with_args(501,context,"User has unlimited credits!");
     return 0;
   }
 
@@ -1526,16 +1516,17 @@ int do_site_take(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_
 }
 
 
-void do_site_help_su(wzd_context_t * context)
+int do_site_help_su(UNUSED wzd_string_t *cname, UNUSED wzd_string_t *command_line, wzd_context_t * context)
 {
   send_message_with_args(501,context,"site su <user>");
+  return 0;
 }
 
 /** site su: become another user
  *
  * su user
  */
-int do_site_su(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t * context)
+int do_site_su(wzd_string_t *cname, wzd_string_t *command_line, wzd_context_t * context)
 {
   wzd_string_t *username;
   int ret;
@@ -1548,13 +1539,12 @@ int do_site_su(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
 
   username = str_tok(command_line," \t\r\n");
   if (!username) {
-    do_site_help_su(context);
-    return 0;
+    return do_site_help_su(cname,command_line,context);
   }
 
   /* check if user already exists */
   if ( backend_find_user(str_tochar(username),&user,&uid) ) {
-    ret = send_message_with_args(501,context,"User does not exists");
+    ret = send_message_with_args(501,context,"User does not exist");
     str_deallocate(username);
     return 0;
   }
@@ -1562,7 +1552,7 @@ int do_site_su(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
 
   /* for now, this command is strictly restricted to siteops */
   if (!me || !me->flags || !strchr(me->flags,FLAG_SITEOP)) {
-    ret = send_message_with_args(501,context,"You can't use this command, you are not siteop!");
+    ret = send_message_with_args(501,context,"You can't use this command, you are not a siteop!");
     return 0;
   }
 
@@ -1608,7 +1598,7 @@ int do_site_su(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
     else
       remote_host = h->h_name;
     log_message("DOPPEL","%s (%s) \"%s\" \"%s\" \"%s\"",
-        (remote_host)?remote_host:"no host !",
+        (remote_host)?remote_host:"no host!",
         inet_str,
         me->username,
         (groupname)?groupname:"No Group",
@@ -1617,9 +1607,9 @@ int do_site_su(wzd_string_t *ignored, wzd_string_t *command_line, wzd_context_t
   }
 
   if (ret) {
-    ret = send_message_with_args(501,context,"Command Failed");
+    ret = send_message_with_args(501,context,"Command failed");
   } else {
-    ret = send_message_with_args(200,context,"Command OK");
+    ret = send_message_with_args(200,context,"Command okay");
   }
   return 0;
 }
