@@ -535,7 +535,7 @@ int tls_auth_cont(wzd_context_t * context)
     status = SSL_accept(ssl);
     sslerr = SSL_get_error(ssl,status);
     if (status == 1) {
-      out_log(LEVEL_FLOOD,"control connection succesfully switched to ssl (cipher: %s)\n",SSL_get_cipher(ssl));
+      out_log(LEVEL_INFO,"control connection succesfully switched to ssl (cipher: %s)\n",SSL_get_cipher(ssl));
       ret = 1;
       break;
     } else {
@@ -690,7 +690,7 @@ int tls_auth_data_cont(wzd_context_t * context)
     sslerr = SSL_get_error(ssl,status);
 
     if (status==1) {
-      out_err(LEVEL_INFO,"Data connection successfully switched to ssl mode\n");
+      out_log(LEVEL_INFO,"Data connection succesfully switched to ssl (cipher: %s)\n",SSL_get_cipher(ssl));
       context->tls_data_mode = TLS_PRIV;
       return 0;
     } else {
@@ -967,12 +967,48 @@ int tls_auth (const char *type, wzd_context_t * context)
   int was_writing=0;
   fd_set fd_r, fd_w;
   struct timeval tv;
+  wzd_string_t * str;
+  char * tls_cipher_list;
 
 
   session = initialize_tls_session(GNUTLS_SERVER);
 
   gnutls_transport_set_ptr(session, (gnutls_transport_ptr) fd);
 
+  {
+    str = config_get_string(mainConfig->cfg_file, "GLOBAL", "tls_cipher_list", NULL);
+    if (str) {
+      /** \bug FIXME memory leak here !! */
+      tls_cipher_list = strdup(str_tochar(str));
+      str_deallocate(str);
+    } else {
+      tls_cipher_list = "ALL";
+    }
+  }
+
+  /** \todo XXX parse TLS cipher names */
+  {
+    /** Note that the priority is set on the client. The server does not use
+     * the algorithm's priority except for disabling algorithms that were not
+     * specified.
+     */
+    const int cipherPriority[] =
+    {
+      GNUTLS_CIPHER_ARCFOUR_128,
+      GNUTLS_CIPHER_3DES_CBC,
+      GNUTLS_CIPHER_AES_128_CBC,
+      GNUTLS_CIPHER_AES_256_CBC,
+      GNUTLS_CIPHER_ARCFOUR_40,
+#if ( (LIBGNUTLS_VERSION_MAJOR > 1) || (LIBGNUTLS_VERSION_MINOR >= 3) )
+      GNUTLS_CIPHER_RC2_40_CBC,
+      GNUTLS_CIPHER_DES_CBC,
+#endif
+      0
+    };
+
+    gnutls_cipher_set_priority(session, cipherPriority);
+  }
+
   /* ensure socket is non-blocking */
 #if defined(_MSC_VER) || (defined(__CYGWIN__) && defined(WINSOCK_SUPPORT))
     {
@@ -1074,6 +1110,7 @@ int tls_init_datamode(int sock, wzd_context_t * context)
   do {
     ret = gnutls_handshake(session);
     if (ret == 0) {
+      out_log(LEVEL_FLOOD,"Data connection succesfully switched to ssl (cipher: %s)\n",gnutls_cipher_get_name(gnutls_cipher_get(session)));
       break;
     }
     if (gnutls_error_is_fatal(ret)) {
